@@ -54,11 +54,18 @@ class Kable:
         else:
             self.debug = False
 
-        if "recordAuthentication" in config:
-            self.recordAuthentication = config["recordAuthentication"]
+        if "disable_cache" in config:
+            self.disableCache = config["disable_cache"]
+            if self.disableCache:
+                print("Starting Kable with disable_cache enabled")
+        else:
+            self.disableCache = False
+
+        if "record_authentication" in config:
+            self.recordAuthentication = config["record_authentication"]
             if self.recordAuthentication is False:
                 print(
-                    "Starting Kable with recordAuthentication disabled, authentication requests will not be recorded")
+                    "Starting Kable with record_authentication disabled, authentication requests will not be recorded")
         else:
             self.recordAuthentication = True
 
@@ -205,6 +212,8 @@ class Kable:
         event['library'] = library
 
         self.queue.append(event)
+        if self.disableCache:
+            self.flushQueue()
 
     def flushQueue(self):
         if self.debug:
